@@ -1,6 +1,6 @@
 /*
 
-  Copyright (c) 2012-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -28,7 +28,7 @@ class FilterActionStatus : public FilterActionWithStringList
 {
     Q_OBJECT
 public:
-    FilterActionStatus(const QString &name, const QString &label, QObject *parent = Q_NULLPTR);
+    FilterActionStatus(const QString &name, const QString &label, QObject *parent = nullptr);
     SearchRule::RequiredPart requiredPart() const Q_DECL_OVERRIDE;
     bool isEmpty() const Q_DECL_OVERRIDE;
     void argsFromString(const QString &argsStr) Q_DECL_OVERRIDE;
