@@ -44,7 +44,7 @@ class Q_DECL_HIDDEN FilterActionWidget::Private
 {
 public:
     Private(FilterActionWidget *qq)
-        : q(qq), mComboBox(0), mAdd(0), mRemove(0), mLayout(0)
+        : q(qq), mComboBox(nullptr), mAdd(nullptr), mRemove(nullptr), mLayout(nullptr)
     {
     }
 
@@ -54,7 +54,7 @@ public:
         mActionList.clear();
     }
 
-    void setFilterAction(QWidget *widget = Q_NULLPTR);
+    void setFilterAction(QWidget *widget = nullptr);
 
     void slotFilterTypeChanged(int index);
     void slotAddWidget();
@@ -98,7 +98,7 @@ void FilterActionWidget::Private::slotFilterTypeChanged(int index)
 {
     setFilterAction(index < mActionList.count() ?
                     mActionList.at(index)->createParamWidget(q) :
-                    0);
+                    nullptr);
 }
 
 FilterActionWidget::FilterActionWidget(QWidget *parent)
@@ -243,7 +243,7 @@ FilterAction *FilterActionWidget::action() const
         }
     }
 
-    return 0;
+    return nullptr;
 }
 
 //=============================================================================
@@ -256,7 +256,7 @@ class FilterActionWidgetLister::Private
 {
 public:
     Private(FilterActionWidgetLister *qq)
-        : q(qq), mActionList(0)
+        : q(qq), mActionList(nullptr)
     {
     }
 
@@ -310,7 +310,7 @@ void FilterActionWidgetLister::setActionList(QList<FilterAction *> *list)
 
     if (list->isEmpty()) {
         slotClear();
-        connectWidget(widgets().constFirst(), 0);
+        connectWidget(widgets().constFirst(), nullptr);
         widgets().constFirst()->blockSignals(false);
         return;
     }
@@ -400,7 +400,7 @@ void FilterActionWidgetLister::reset()
         d->regenerateActionListFromWidgets();
     }
 
-    d->mActionList = 0;
+    d->mActionList = nullptr;
     slotClear();
 
     static_cast<QWidget *>(parent())->setEnabled(false);
@@ -424,7 +424,7 @@ void FilterActionWidgetLister::clearWidget(QWidget *widget)
 {
     if (widget) {
         FilterActionWidget *w = static_cast<FilterActionWidget *>(widget);
-        w->setAction(0);
+        w->setAction(nullptr);
         w->disconnect(this);
         reconnectWidget(w);
         updateAddRemoveButton();
