@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -106,7 +106,7 @@ void FilterSelectionDialog::setFilters(const QList<MailFilter *> &filters)
     originalFilters = filters;
     filtersListWidget->clear();
 
-    foreach (const MailFilter *filter, filters) {
+    for (const MailFilter *filter : filters) {
         QListWidgetItem *item = new QListWidgetItem(filter->name(), filtersListWidget);
         item->setFlags(Qt::ItemIsUserCheckable | Qt::ItemIsEnabled);
         item->setCheckState(Qt::Checked);
