@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -52,7 +52,7 @@ void KMFilterAccountList::updateAccountList(MailCommon::MailFilter *filter)
 {
     clear();
 
-    QTreeWidgetItem *top = Q_NULLPTR;
+    QTreeWidgetItem *top = nullptr;
     // Block the signals here, otherwise we end up calling
     // slotApplicableAccountsChanged(), which will read the incomplete item
     // state and write that back to the filter
@@ -101,7 +101,7 @@ void KMFilterAccountList::applyOnAccount(const QStringList &lstAccount)
 {
     clear();
 
-    QTreeWidgetItem *top = Q_NULLPTR;
+    QTreeWidgetItem *top = nullptr;
     // Block the signals here, otherwise we end up calling
     // slotApplicableAccountsChanged(), which will read the incomplete item
     // state and write that back to the filter
