@@ -3,7 +3,7 @@
   Author: Marc Mutz <mutz@kde.org>
   based upon work by Stefan Taferner <taferner@kde.org>
 
-  Copyright (c) 2011-2015 Laurent Montel <montel@kde.org>
+  Copyright (c) 2011-2017 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -85,7 +85,7 @@ using namespace MailCommon;
 KMFilterDialog::KMFilterDialog(const QList<KActionCollection *> &actionCollection,
                                QWidget *parent, bool createDummyFilter)
     : QDialog(parent),
-      mFilter(0),
+      mFilter(nullptr),
       mDoNotClose(false),
       mIgnoreFilterUpdates(true)
 {
@@ -490,7 +490,7 @@ void KMFilterDialog::slotRunFilters()
 
 void KMFilterDialog::slotFetchItemsForFolderDone(KJob *job)
 {
-    Akonadi::ItemFetchJob *fjob = dynamic_cast<Akonadi::ItemFetchJob *>(job);
+    Akonadi::ItemFetchJob *fjob = qobject_cast<Akonadi::ItemFetchJob *>(job);
     Q_ASSERT(fjob);
 
     QStringList filtersId;
@@ -569,7 +569,7 @@ void KMFilterDialog::slotFilterSelected(MailFilter *aFilter)
 
 void KMFilterDialog::slotReset()
 {
-    mFilter = 0;
+    mFilter = nullptr;
     mPatternEdit->reset();
 
     mActionLister->reset();
@@ -782,6 +782,6 @@ void KMFilterDialog::slotExportAsSieveScript()
 
 void KMFilterDialog::slotHelp()
 {
-    PimCommon::Util::invokeHelp(QStringLiteral("kmail/filters.html"));
+    PimCommon::Util::invokeHelp(QStringLiteral("kmail2/filters.html"));
 }
 
