@@ -30,7 +30,7 @@
 #include "dialog/filteractionmissingaccountdialog.h"
 using MailCommon::FilterLog;
 
-#include "PimCommon/PimUtil"
+#include <PimCommon/PimUtil>
 
 // KDEPIMLIBS headers
 #include <AgentManager>
@@ -433,7 +433,7 @@ bool MailFilter::readConfig(const KConfigGroup &config, bool interactive)
     int numActions = config.readEntry("actions", 0);
     if (numActions > filterActionsMaximumSize()) {
         numActions = filterActionsMaximumSize();
-        KMessageBox::information(0, i18n("<qt>Too many filter actions in filter rule <b>%1</b>.</qt>", mPattern.name()));
+        KMessageBox::information(nullptr, i18n("<qt>Too many filter actions in filter rule <b>%1</b>.</qt>", mPattern.name()));
     }
 
     for (int i = 0; i < numActions; ++i) {
@@ -467,7 +467,7 @@ bool MailFilter::readConfig(const KConfigGroup &config, bool interactive)
                 }
             }
         } else
-            KMessageBox::information(0 /* app-global modal dialog box */,
+            KMessageBox::information(nullptr /* app-global modal dialog box */,
                                      i18n("<qt>Unknown filter action <b>%1</b><br />in filter rule <b>%2</b>.<br />Ignoring it.</qt>",
                                           config.readEntry(actName, QString()),
                                           mPattern.name()));
@@ -504,7 +504,8 @@ void MailFilter::generateSieveScript(QStringList &requires, QString &code)
             code += QLatin1Char('\n');
         }
         code += QLatin1String("    ") + (*it)->sieveCode();
-        Q_FOREACH (const QString &str, (*it)->sieveRequires()) {
+        const QStringList lstRequires = (*it)->sieveRequires();
+        for (const QString &str : lstRequires) {
             if (!requires.contains(str)) {
                 requires.append(str);
             }
