@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -17,7 +17,7 @@
 
 #include "accountconfigorderdialog.h"
 #include "mailcommonsettings_base.h"
-#include "PimCommon/PimUtil"
+#include <PimCommon/PimUtil>
 #include "util/mailutil.h"
 #include "mailcommon_debug.h"
 #include <KLocalizedString>
@@ -41,16 +41,19 @@ using namespace MailCommon;
 struct InstanceStruct {
     QString name;
     QIcon icon;
+    bool isValid() const {
+        return !name.isEmpty();
+    }
 };
 
 class MailCommon::AccountConfigOrderDialogPrivate
 {
 public:
     AccountConfigOrderDialogPrivate()
-        : mListAccount(Q_NULLPTR),
-          mUpButton(Q_NULLPTR),
-          mDownButton(Q_NULLPTR),
-          mEnableAccountOrder(Q_NULLPTR)
+        : mListAccount(nullptr),
+          mUpButton(nullptr),
+          mDownButton(nullptr),
+          mEnableAccountOrder(nullptr)
     {
 
     }
@@ -65,7 +68,7 @@ AccountConfigOrderDialog::AccountConfigOrderDialog(QWidget *parent)
       d(new MailCommon::AccountConfigOrderDialogPrivate)
 {
     setWindowTitle(i18n("Edit Accounts Order"));
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
 
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
@@ -81,7 +84,7 @@ AccountConfigOrderDialog::AccountConfigOrderDialog(QWidget *parent)
     vbox->setMargin(0);
     page->setLayout(vbox);
 
-    d->mEnableAccountOrder = new QCheckBox(i18n("Use custom order"));
+    d->mEnableAccountOrder = new QCheckBox(i18n("Use custom order"), this);
     connect(d->mEnableAccountOrder, &QCheckBox::clicked, this, &AccountConfigOrderDialog::slotEnableAccountOrder);
     vbox->addWidget(d->mEnableAccountOrder);
 
@@ -186,7 +189,8 @@ void AccountConfigOrderDialog::init()
     QStringList instanceList;
 
     QMap<QString, InstanceStruct> mapInstance;
-    foreach (const Akonadi::AgentInstance &instance, Akonadi::AgentManager::self()->instances()) {
+    const Akonadi::AgentInstance::List lstInstances = Akonadi::AgentManager::self()->instances();
+    for (const Akonadi::AgentInstance &instance : lstInstances) {
         const QStringList capabilities(instance.type().capabilities());
         if (instance.type().mimeTypes().contains(KMime::Message::mimeType())) {
             if (capabilities.contains(QStringLiteral("Resource")) &&
@@ -226,8 +230,8 @@ void AccountConfigOrderDialog::init()
     const int numberOfElement(finalList.count());
     for (int i = 0; i < numberOfElement; ++i) {
         const QString identifier(finalList.at(i));
-        if (mapInstance.contains(identifier)) {
-            InstanceStruct tmp = mapInstance.value(identifier);
+        const InstanceStruct tmp = mapInstance.value(identifier);
+        if (tmp.isValid()) {
             QListWidgetItem *item = new QListWidgetItem(tmp.icon, tmp.name, d->mListAccount);
             item->setData(AccountConfigOrderDialog::IdentifierAccount, identifier);
             d->mListAccount->addItem(item);
@@ -242,6 +246,7 @@ void AccountConfigOrderDialog::slotOk()
 {
     QStringList order;
     const int numberOfItems(d->mListAccount->count());
+    order.reserve(numberOfItems);
     for (int i = 0; i < numberOfItems; ++i) {
         order << d->mListAccount->item(i)->data(AccountConfigOrderDialog::IdentifierAccount).toString();
     }
