@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -359,7 +359,7 @@ bool SearchRuleString::matchesInternal(const QString &msgContents) const
 
                 const KContacts::Addressee::List contacts = job->contacts();
 
-                foreach (const KContacts::Addressee &contact, contacts) {
+                for (const KContacts::Addressee &contact : contacts) {
                     if (contact.hasCategory(category)) {
                         return true;
                     }
@@ -383,7 +383,7 @@ bool SearchRuleString::matchesInternal(const QString &msgContents) const
 
                 const KContacts::Addressee::List contacts = job->contacts();
 
-                foreach (const KContacts::Addressee &contact, contacts) {
+                for (const KContacts::Addressee &contact : contacts) {
                     if (contact.hasCategory(category)) {
                         return false;
                     }
