@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -38,7 +38,7 @@ class MAILCOMMON_EXPORT TagWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit TagWidget(const QList<KActionCollection *> &actionCollections, QWidget *parent = Q_NULLPTR);
+    explicit TagWidget(const QList<KActionCollection *> &actionCollections, QWidget *parent = nullptr);
     ~TagWidget();
 
     void recordTagSettings(MailCommon::Tag::Ptr tag);
